@@ -24,15 +24,22 @@ from sslyze.errors import ServerRejectedTlsHandshake
 from sslyze.server_connectivity import ServerConnectivityInfo, TlsVersionEnum, ClientAuthRequirementEnum
 
 
-class RobotScanResultEnum(Enum):
-    """An enum to provide the result of running a RobotScanCommand.
+class RobotScanResultEnum(str, Enum):
+    """The result of attempting exploit the ROBOT issue on the server.
+
+    Attributes:
+        VULNERABLE_WEAK_ORACLE: The server is vulnerable but the attack would take too long.
+        VULNERABLE_STRONG_ORACLE: The server is vulnerable and real attacks are feasible.
+        NOT_VULNERABLE_NO_ORACLE: The server supports RSA cipher suites but does not act as an oracle.
+        NOT_VULNERABLE_RSA_NOT_SUPPORTED: The server does not supports RSA cipher suites.
+        UNKNOWN_INCONSISTENT_RESULTS: Could not determine whether the server is vulnerable or not.
     """
 
-    VULNERABLE_WEAK_ORACLE = 1  #: The server is vulnerable but the attack would take too long
-    VULNERABLE_STRONG_ORACLE = 2  #: The server is vulnerable and real attacks are feasible
-    NOT_VULNERABLE_NO_ORACLE = 3  #: The server supports RSA cipher suites but does not act as an oracle
-    NOT_VULNERABLE_RSA_NOT_SUPPORTED = 4  #: The server does not supports RSA cipher suites
-    UNKNOWN_INCONSISTENT_RESULTS = 5  #: Could not determine whether the server is vulnerable or not
+    VULNERABLE_WEAK_ORACLE = "VULNERABLE_WEAK_ORACLE"
+    VULNERABLE_STRONG_ORACLE = "VULNERABLE_STRONG_ORACLE"
+    NOT_VULNERABLE_NO_ORACLE = "NOT_VULNERABLE_NO_ORACLE"
+    NOT_VULNERABLE_RSA_NOT_SUPPORTED = "NOT_VULNERABLE_RSA_NOT_SUPPORTED"
+    UNKNOWN_INCONSISTENT_RESULTS = "UNKNOWN_INCONSISTENT_RESULTS"
 
 
 class RobotPmsPaddingPayloadEnum(Enum):
